@@ -151,7 +151,7 @@ class Interface:
 
         return SolveEvent.TimeEvent
 
-    def get_event_results(self, t: float, y: np.array) -> np.array:
+    def get_event_results(self, t: float, y: np.array) -> Optional[np.array]:
         """Function called to find events. Used together with event directions to determine if an event occured.
 
         :param t: time
@@ -160,12 +160,12 @@ class Interface:
         :type y: :class:`numpy.ndarray`
 
         :return: list of values for the all events connected to the model. The triggered event is found using a \
-        bisection method, and it's index is passed to run_event_action.
-        :rtype: :class:`numpy.ndarray`
+        bisection method, and it's index is passed to run_event_action, or None (for no events).
+        :rtype: :class:`numpy.ndarray` or None
 
         """
 
-        return np.array([0], dtype='float')
+        pass
 
     def run_event_action(self, t_event: float, y: np.array, event_idx: int) -> np.array:
         """Function called each time an event has been found, and can be used to trigger an action. The event_id is used
@@ -182,17 +182,18 @@ class Interface:
         """
         return y
 
-    def get_next_time_event(self, t) -> tuple[int, float]:
+    def get_next_time_event(self, t) -> Optional[tuple[int, float]]:
         """
         Function that is called after each converged solver step. Returns a tuple which contains an index of the next
         time event action function to be trigged, and the value of the time-step when the function is triggered.
 
         :param t: current time
         :type t: float
-        :return: tuple of index of event function and next time. If no function is triggered, it should return -1, -1.
-        :rtype: tuple[int, float]
+        :return: Optional: tuple of index of event function and next time. If no function is triggered, it should return
+            None.
+        :rtype: Optional[tuple[int, float]]
         """
-        return -1, -1
+        pass
 
     def get_event_directions(self) -> np.array:
         """
@@ -302,7 +303,18 @@ class _JitHelper:
         self.model_class = model_class
         self.args = args
         self.kwargs = kwargs
-        self.python_model = model_class(*args, **kwargs)
+        self.python_model = None
+
+        args_ = []
+        kwargs_ = {}
+        for arg in args:
+            if isinstance(arg, _JitHelper):
+                args_.append(arg.python_model)
+        for k, v in kwargs.items():
+            if isinstance(v, _JitHelper):
+                kwargs_.update({k: v.python_model})
+
+        self.python_model = model_class(*args_, **kwargs_)
         self.compiled_model = None
 
         #  Make functions available to ModelWrapper
@@ -410,7 +422,6 @@ class _JitHelper:
             setattr(self.compiled_model, k, getattr(v, 'compiled_model', v))
 
 
-
 class Model:
     """Helper class to decorate models.
     Holds the python model, interface and compiled model (generated once solver is compiled).
@@ -465,22 +476,19 @@ class Model:
         """
         return cls(model_class, interface=None, iscomponent=True)
 
-
-    def generate_interface(self, jit=True) -> Interface:
-        """Method used by :class:`solver.numerous_solver.NumerousSolver` to generate model interface
-
-        :param jit: if True then use numba to jit
-        :type jit: bool
-        :return: Returns the generated model interface
-        :rtype: :class:`solver.interface.Interface`
+    def load_interface(self) -> type(Interface):
         """
+        Method to load interface belonging to model
 
+        :return:
+        :rtype:
+        """
         #  If no interface specified try default interface
         if not self._interface:
             self._interface = f"{self.model_class.__name__}Interface"
 
         #  If interface is string, use inspect to import module. Must be in same file as model class.
-        interface = None
+        interface = Interface
         if type(self._interface) == str:
             interface = getattr(inspect.getmodule(self.model_class), self._interface)
         elif hasattr(self._interface, '__class__') and self._interface.__bases__[0] == Interface:
@@ -490,6 +498,33 @@ class Model:
         assert interface, "No interface was instantiated"
         assert interface.__bases__[0] == Interface, "Unknown type of interface"
 
+        interface_instance = interface(self.python_model)
+
+        has_events = interface_instance.get_event_results(0, interface_instance.get_states()) is not None
+        has_time_events = interface_instance.get_next_time_event(0) is not None
+
+        def get_event_results_mock(self, t, y):
+            return np.array([0], dtype='float')
+
+        def get_next_time_event_mock(self, t):
+            return -1, -1
+
+        if not has_events:
+            interface.get_event_results = get_event_results_mock
+        if not has_time_events:
+            interface.get_next_time_event = get_next_time_event_mock
+
+        return interface
+
+    def generate_interface(self, jit=True) -> Interface:
+        """Method used by :class:`solver.numerous_solver.NumerousSolver` to generate model interface
+
+        :param jit: if True then use numba to jit
+        :type jit: bool
+        :return: Returns the generated model interface
+        :rtype: :class:`solver.interface.Interface`
+        """
+        interface = self.load_interface()
         model_ = self.jithelper(jit=jit)
         self.interface = _JitHelper.jithelper(interface, jit)(model_)
         self._interface_dict = interface(model_).__dict__  # Instantiate interface to get its default values
