@@ -79,27 +79,11 @@ class NumerousSolver:
             raise ValueError(f"Unknown method {self.options.get('method', 'RK45')}, "
                              f"allowed methods: {list(solver_methods.keys())}")
 
-        if self.g:
-            self.number_of_events = len(self.g)
-        else:
-            self.number_of_events = 0
+        self.number_of_events = len(self.g)
 
-
-        class SolverEventHandler:
-            """
-            Class to allow model to return None for get_event_results
-            """
-            def __init__(self, interface: Interface, has_events: bool):
-                self.interface = interface
-                self._has_events = has_events
-            def get_event_results(self, t, y):
-                if self._has_events:
-                    return self.interface.get_event_results(t, y)
-                else:
-                    return np.array([0], dtype='float')
-
-        self.solvereventhandler = _JitHelper.jithelper(SolverEventHandler, jit=use_jit)(interface=self.interface,
-                                                                             has_events=self.number_of_events > 0)
+        self.has_time_events = False
+        if self.interface.get_next_time_event(0) is not None:
+            self.has_time_events = True
 
         self.interface.set_states(y0)
 
@@ -114,7 +98,6 @@ class NumerousSolver:
         if self.use_jit:
             self._non_compiled_solve = njit(self._generate_solver())
             self._solve = self._compile_solver()
-            #self._solve = self.generate_solver()
         else:
             self._solve = self._generate_solver()
 
@@ -122,7 +105,7 @@ class NumerousSolver:
 
 
     def _generate_solver(self):
-        def _solve(interface, solvereventhandler, _solve_state, initial_step, dt_0, order, order_, roller, strict_eval,
+        def _solve(interface, _solve_state, initial_step, dt_0, order, order_, roller, strict_eval,
                    min_step, max_step, step_integrate_, g, number_of_events, step_converged, event_trigger,
                    t0=0.0, t_end=1000.0, t_eval=np.linspace(0.0, 1000.0, 100), ix_eval=1, event_tolerance=1e-6) -> _Info:
 
@@ -295,27 +278,25 @@ class NumerousSolver:
                     else:
                         te_array[2] = max(te_array)
 
-                    if number_of_events > 0:
+                    g_new = interface.get_event_results(t, y)
 
-                        g_new = solvereventhandler.get_event_results(t, y)
+                    up = (g <= 0) & (g_new >= 0) & (interface.get_event_directions() == 1)
+                    down = (g >= 0) & (g_new <= 0) & (interface.get_event_directions() == -1)
+                    g = g_new
 
-                        up = (g <= 0) & (g_new >= 0) & (interface.get_event_directions() == 1)
-                        down = (g >= 0) & (g_new <= 0) & (interface.get_event_directions() == -1)
-                        g = g_new
+                    for ix in np.concatenate((np.argwhere(up), np.argwhere(down))):
+                        eps = 1.e-6  # for case to t_event = t
+                        status, t_event, y_event = check_event(interface.get_event_results, ix[0],
+                                                               t_previous, y_previous, t, y)
+                        t_events[ix[0]] = t_event - eps
+                        y_events[:, ix[0]] = y_event
 
-                        for ix in np.concatenate((np.argwhere(up), np.argwhere(down))):
-                            eps = 1.e-6  # for case to t_event = t
-                            status, t_event, y_event = check_event(solvereventhandler.get_event_results, ix[0],
-                                                                   t_previous, y_previous, t, y)
-                            t_events[ix[0]] = t_event - eps
-                            y_events[:, ix[0]] = y_event
-
-                if number_of_events > 0 and min(t_events) < t:
+                if min(t_events) < t:
                     event_trigger = True
                     event_ix = np.argmin(t_events)
                     t_event = t_events[event_ix]
                     y_event = y_events[:, event_ix]
-                    g = solvereventhandler.get_event_results(t_event, y_event)
+                    g = interface.get_event_results(t_event, y_event)
 
                 if not event_trigger and step_converged:
                     y_previous = y
@@ -335,7 +316,7 @@ class NumerousSolver:
                         t_event_previous = t_event
                         step_converged = False  # roll back and refine search
                         dt = initial_step
-                        g = solvereventhandler.get_event_results(t, y_previous)
+                        g = interface.get_event_results(t, y_previous)
                     else:
                         interface.set_states(y_event)
                         y_previous = interface.run_event_action(t_event, y_event, event_ix)
@@ -398,7 +379,6 @@ class NumerousSolver:
         order_ = 0
 
         args = (self.interface,
-                self.solvereventhandler,
                 self._method.get_solver_state(),
                 initial_step,
                 initial_step,
@@ -534,14 +514,14 @@ class NumerousSolver:
         t_start = t_eval[0]
         t_end = t_eval[-1]
 
-        info = self._solve(self.interface, self.solvereventhandler, solve_state, initial_step, dt, order, order_,
+        info = self._solve(self.interface, solve_state, initial_step, dt, order, order_,
                            roller, strict_eval, min_step, max_step, step_integrate_, g, self.number_of_events,
                            step_converged, event_trigger, t_start, t_end, t_eval, 1, atol*100)
 
         while info.status == SolveStatus.Running:
             self.event_handler.handle_solve_event(self.interface, info.event_id, info.t)
 
-            info = self._solve(self.interface, self.solvereventhandler, info.solve_state, initial_step, info.dt, order,
+            info = self._solve(self.interface, info.solve_state, initial_step, info.dt, order,
                                info.order_, info.roller, strict_eval, min_step, max_step, step_integrate_, info.g,
                                self.number_of_events, info.step_converged, info.event_trigger, info.t, t_end, t_eval,
                                info.ix_eval, atol*100)
